@@ -1,5 +1,3 @@
 from pipereport.runner.runner import PipeRunner
 
-__all__ = [
-    'PipeRunner'
-]
+__all__ = ["PipeRunner"]
